pub struct Dithering {
pub is_enabled: bool,
pub matrix: DitherMatrix,
}Expand description
Configures the dithering algorithm applied during color quantization.
Dithering is a technique used to create the illusion of more colors when working with a limited palette. It is only applied when not in truecolor mode.
Fields
is_enabled: boolSet to true to enable dithering.
matrix: DitherMatrixThe dithering matrix/algorithm to use. Currently, only one option is
available via imagequant, but this field is for future expansion.